# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from af_licence_manager.api_client import ApiClient


class DefaultApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def header_data(self, **kwargs):  # noqa: E501
        """header_data  # noqa: E501

        This operation is just for documenting the various header parameters accepted/required at most operations additionally besides the explicit parameters. See the operation descriptions for details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.header_data(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_af_accept_version:
        :param str x_af_security_token: May also stem from the corresponding cookie. It is set by OrgmodelManager/GlobalSecurityManager. This is Base64-URL-encoded (RFC 4648, table 2)!
        :param str x_af_caller_uri: May also stem from the corresponding cookie. It is set by OrgmodelManager/GlobalSecurityManager.
        :param str x_af_session_id: An optional session ID (UUID). This allows to combine several requests in one session, similar to transactions. If this is not provided, a random UUID will be used thus leading to an individual for the request.
        :param str x_af_add_url_enc_attr: Key-value pairs, separated by '='. Keys and values should be URL-encoded. There may be several fields in the header.
        :param bool x_af_exception_stack: Whether to keep the stacks in exceptional responses. This will override the server configuration to suppress them. The value is irrelevant only the existence of the header will be checked.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.header_data_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.header_data_with_http_info(**kwargs)  # noqa: E501
            return data

    def header_data_with_http_info(self, **kwargs):  # noqa: E501
        """header_data  # noqa: E501

        This operation is just for documenting the various header parameters accepted/required at most operations additionally besides the explicit parameters. See the operation descriptions for details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.header_data_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_af_accept_version:
        :param str x_af_security_token: May also stem from the corresponding cookie. It is set by OrgmodelManager/GlobalSecurityManager. This is Base64-URL-encoded (RFC 4648, table 2)!
        :param str x_af_caller_uri: May also stem from the corresponding cookie. It is set by OrgmodelManager/GlobalSecurityManager.
        :param str x_af_session_id: An optional session ID (UUID). This allows to combine several requests in one session, similar to transactions. If this is not provided, a random UUID will be used thus leading to an individual for the request.
        :param str x_af_add_url_enc_attr: Key-value pairs, separated by '='. Keys and values should be URL-encoded. There may be several fields in the header.
        :param bool x_af_exception_stack: Whether to keep the stacks in exceptional responses. This will override the server configuration to suppress them. The value is irrelevant only the existence of the header will be checked.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_af_accept_version', 'x_af_security_token', 'x_af_caller_uri', 'x_af_session_id', 'x_af_add_url_enc_attr', 'x_af_exception_stack']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method header_data" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_af_accept_version' in params:
            header_params['x-AF-Accept-Version'] = params['x_af_accept_version']  # noqa: E501
        if 'x_af_security_token' in params:
            header_params['x-AF-Security-Token'] = params['x_af_security_token']  # noqa: E501
        if 'x_af_caller_uri' in params:
            header_params['x-AF-Caller-URI'] = params['x_af_caller_uri']  # noqa: E501
        if 'x_af_session_id' in params:
            header_params['x-AF-Session-ID'] = params['x_af_session_id']  # noqa: E501
        if 'x_af_add_url_enc_attr' in params:
            header_params['x-AF-Add-UrlEnc-Attr'] = params['x_af_add_url_enc_attr']  # noqa: E501
        if 'x_af_exception_stack' in params:
            header_params['x-AF-Exception-Stack'] = params['x_af_exception_stack']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/header-data', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import af_licence_manager
from af_licence_manager.api.licence_manager_api import LicenceManagerApi  # noqa: E501
from af_licence_manager.rest import ApiException


class TestLicenceManagerApi(unittest.TestCase):
    """LicenceManagerApi unit test stubs"""

    def setUp(self):
        self.api = LicenceManagerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_licence_information(self):
        """Test case for get_licence_information

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class QualifiedAgent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'agent_id': 'int',
        'agent_name': 'str',
        'org_pos_id': 'int',
        'org_pos_name': 'str',
        'user_session_id': 'str'
    }

    attribute_map = {
        'agent_id': 'agentId',
        'agent_name': 'agentName',
        'org_pos_id': 'orgPosId',
        'org_pos_name': 'orgPosName',
        'user_session_id': 'userSessionId'
    }

    def __init__(self, agent_id=None, agent_name=None, org_pos_id=None, org_pos_name=None, user_session_id=None):  # noqa: E501
        """QualifiedAgent - a model defined in Swagger"""  # noqa: E501
        self._agent_id = None
        self._agent_name = None
        self._org_pos_id = None
        self._org_pos_name = None
        self._user_session_id = None
        if not(hasattr(self, "discriminator")) or not(self.discriminator):
            self.discriminator = None
        self.agent_id = agent_id
        self.agent_name = agent_name
        self.org_pos_id = org_pos_id
        self.org_pos_name = org_pos_name
        if user_session_id is not None:
            self.user_session_id = user_session_id

    @property
    def agent_id(self):
        """Gets the agent_id of this QualifiedAgent.  # noqa: E501


        :return: The agent_id of this QualifiedAgent.  # noqa: E501
        :rtype: int
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """Sets the agent_id of this QualifiedAgent.


        :param agent_id: The agent_id of this QualifiedAgent.  # noqa: E501
        :type: int
        """
        if agent_id is None:
            raise ValueError("Invalid value for `agent_id`, must not be `None`")  # noqa: E501

        self._agent_id = agent_id

    @property
    def agent_name(self):
        """Gets the agent_name of this QualifiedAgent.  # noqa: E501


        :return: The agent_name of this QualifiedAgent.  # noqa: E501
        :rtype: str
        """
        return self._agent_name

    @agent_name.setter
    def agent_name(self, agent_name):
        """Sets the agent_name of this QualifiedAgent.


        :param agent_name: The agent_name of this QualifiedAgent.  # noqa: E501
        :type: str
        """
        if agent_name is None:
            raise ValueError("Invalid value for `agent_name`, must not be `None`")  # noqa: E501

        self._agent_name = agent_name

    @property
    def org_pos_id(self):
        """Gets the org_pos_id of this QualifiedAgent.  # noqa: E501


        :return: The org_pos_id of this QualifiedAgent.  # noqa: E501
        :rtype: int
        """
        return self._org_pos_id

    @org_pos_id.setter
    def org_pos_id(self, org_pos_id):
        """Sets the org_pos_id of this QualifiedAgent.


        :param org_pos_id: The org_pos_id of this QualifiedAgent.  # noqa: E501
        :type: int
        """
        if org_pos_id is None:
            raise ValueError("Invalid value for `org_pos_id`, must not be `None`")  # noqa: E501

        self._org_pos_id = org_pos_id

    @property
    def org_pos_name(self):
        """Gets the org_pos_name of this QualifiedAgent.  # noqa: E501


        :return: The org_pos_name of this QualifiedAgent.  # noqa: E501
        :rtype: str
        """
        return self._org_pos_name

    @org_pos_name.setter
    def org_pos_name(self, org_pos_name):
        """Sets the org_pos_name of this QualifiedAgent.


        :param org_pos_name: The org_pos_name of this QualifiedAgent.  # noqa: E501
        :type: str
        """
        if org_pos_name is None:
            raise ValueError("Invalid value for `org_pos_name`, must not be `None`")  # noqa: E501

        self._org_pos_name = org_pos_name

    @property
    def user_session_id(self):
        """Gets the user_session_id of this QualifiedAgent.  # noqa: E501


        :return: The user_session_id of this QualifiedAgent.  # noqa: E501
        :rtype: str
        """
        return self._user_session_id

    @user_session_id.setter
    def user_session_id(self, user_session_id):
        """Sets the user_session_id of this QualifiedAgent.


        :param user_session_id: The user_session_id of this QualifiedAgent.  # noqa: E501
        :type: str
        """

        self._user_session_id = user_session_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(QualifiedAgent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QualifiedAgent):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from af_licence_manager.api.arista_flow_service_api import AristaFlowServiceApi
from af_licence_manager.api.licence_manager_api import LicenceManagerApi
from af_licence_manager.api.default_api import DefaultApi
# import ApiClient
from af_licence_manager.api_client import ApiClient
from af_licence_manager.configuration import Configuration
# import models into sdk package
from af_licence_manager.models.abort_service_exception import AbortServiceException
from af_licence_manager.models.abort_transaction_exception import AbortTransactionException
from af_licence_manager.models.agent_unknown_exception import AgentUnknownException
from af_licence_manager.models.authentication_exception import AuthenticationException
from af_licence_manager.models.configuration_exception import ConfigurationException
from af_licence_manager.models.data_consistency_exception import DataConsistencyException
from af_licence_manager.models.data_source_exception import DataSourceException
from af_licence_manager.models.dummy_parent import DummyParent
from af_licence_manager.models.ebp_instance_reference import EbpInstanceReference
from af_licence_manager.models.ilm_exception import IlmException
from af_licence_manager.models.ilm_exception_cause import IlmExceptionCause
from af_licence_manager.models.ilm_exception_stack_trace import IlmExceptionStackTrace
from af_licence_manager.models.ilm_exception_suppressed import IlmExceptionSuppressed
from af_licence_manager.models.incompatible_gui_context_exception import IncompatibleGuiContextException
from af_licence_manager.models.interrupt_exception import InterruptException
from af_licence_manager.models.invalid_activity_state_exception import InvalidActivityStateException
from af_licence_manager.models.invalid_data_container_exception import InvalidDataContainerException
from af_licence_manager.models.invalid_instance_state_exception import InvalidInstanceStateException
from af_licence_manager.models.invalid_template_state_exception import InvalidTemplateStateException
from af_licence_manager.models.licence_information import LicenceInformation
from af_licence_manager.models.lock_exception import LockException
from af_licence_manager.models.org_model_exception import OrgModelException
from af_licence_manager.models.parameter_exception import ParameterException
from af_licence_manager.models.parameter_missing_exception import ParameterMissingException
from af_licence_manager.models.parameter_type_exception import ParameterTypeException
from af_licence_manager.models.password_policy_exception import PasswordPolicyException
from af_licence_manager.models.plain_text_exception import PlainTextException
from af_licence_manager.models.policy_resolution_exception import PolicyResolutionException
from af_licence_manager.models.qualified_agent import QualifiedAgent
from af_licence_manager.models.script_environment_exception import ScriptEnvironmentException
from af_licence_manager.models.script_evaluation_exception import ScriptEvaluationException
from af_licence_manager.models.script_exception import ScriptException
from af_licence_manager.models.service_instance_name import ServiceInstanceName
from af_licence_manager.models.service_not_known_exception import ServiceNotKnownException
from af_licence_manager.models.service_release import ServiceRelease
from af_licence_manager.models.session import Session
from af_licence_manager.models.session_token import SessionToken
from af_licence_manager.models.unknown_session_exception import UnknownSessionException
from af_licence_manager.models.wrapping_exception import WrappingException
from af_licence_manager.models.wrong_agent_exception import WrongAgentException
from af_licence_manager.models.wrong_runtime_manager_exception import WrongRuntimeManagerException



# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from af_licence_manager.models.dummy_parent import DummyParent  # noqa: F401,E501

class IlmException(DummyParent):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'stack_trace': 'list[IlmExceptionStackTrace]',
        'sub_class': 'str',
        'message': 'str',
        'cause_class': 'str',
        'server_log_id': 'str',
        'suppress_stack': 'bool',
        'suppressed': 'list[IlmExceptionSuppressed]'
    }
    if hasattr(DummyParent, "swagger_types"):
        swagger_types.update(DummyParent.swagger_types)

    attribute_map = {
        'stack_trace': 'stackTrace',
        'sub_class': 'subClass',
        'message': 'message',
        'cause_class': 'causeClass',
        'server_log_id': 'serverLogId',
        'suppress_stack': 'suppressStack',
        'suppressed': 'suppressed'
    }
    if hasattr(DummyParent, "attribute_map"):
        attribute_map.update(DummyParent.attribute_map)

    discriminator_value_class_map = {
          'OrgModelException': 'OrgModelException',
'InvalidDataContainerException': 'InvalidDataContainerException',
'InvalidInstanceStateException': 'InvalidInstanceStateException',
'AuthenticationException': 'AuthenticationException',
'WrappingException': 'WrappingException',
'DataConsistencyException': 'DataConsistencyException',
'ScriptException': 'ScriptException',
'WrongAgentException': 'WrongAgentException',
'PolicyResolutionException': 'PolicyResolutionException',
'InvalidActivityStateException': 'InvalidActivityStateException',
'LockException': 'LockException',
'AgentUnknownException': 'AgentUnknownException',
'ParameterException': 'ParameterException',
'AbortTransactionException': 'AbortTransactionException',
'AbortServiceException': 'AbortServiceException',
'IncompatibleGuiContextException': 'IncompatibleGuiContextException',
'UnknownSessionException': 'UnknownSessionException',
'InterruptException': 'InterruptException',
'InvalidTemplateStateException': 'InvalidTemplateStateException',
'PasswordPolicyException': 'PasswordPolicyException',
'DataSourceException': 'DataSourceException',
'PlainTextException': 'PlainTextException',
'WrongRuntimeManagerException': 'WrongRuntimeManagerException'    }

    def __init__(self, stack_trace=None, sub_class=None, message=None, cause_class=None, server_log_id=None, suppress_stack=None, suppressed=None, *args, **kwargs):  # noqa: E501
        """IlmException - a model defined in Swagger"""  # noqa: E501
        self._stack_trace = None
        self._sub_class = None
        self._message = None
        self._cause_class = None
        self._server_log_id = None
        self._suppress_stack = None
        self._suppressed = None
        if not(hasattr(self, "discriminator")) or not(self.discriminator):
            self.discriminator = 'sub_class'
        if stack_trace is not None:
            self.stack_trace = stack_trace
        self.sub_class = sub_class
        self.message = message
        if cause_class is not None:
            self.cause_class = cause_class
        if server_log_id is not None:
            self.server_log_id = server_log_id
        self.suppress_stack = suppress_stack
        if suppressed is not None:
            self.suppressed = suppressed
        DummyParent.__init__(self, *args, **kwargs)

    @property
    def stack_trace(self):
        """Gets the stack_trace of this IlmException.  # noqa: E501


        :return: The stack_trace of this IlmException.  # noqa: E501
        :rtype: list[IlmExceptionStackTrace]
        """
        return self._stack_trace

    @stack_trace.setter
    def stack_trace(self, stack_trace):
        """Sets the stack_trace of this IlmException.


        :param stack_trace: The stack_trace of this IlmException.  # noqa: E501
        :type: list[IlmExceptionStackTrace]
        """

        self._stack_trace = stack_trace

    @property
    def sub_class(self):
        """Gets the sub_class of this IlmException.  # noqa: E501


        :return: The sub_class of this IlmException.  # noqa: E501
        :rtype: str
        """
        return self._sub_class

    @sub_class.setter
    def sub_class(self, sub_class):
        """Sets the sub_class of this IlmException.


        :param sub_class: The sub_class of this IlmException.  # noqa: E501
        :type: str
        """
        if sub_class is None:
            raise ValueError("Invalid value for `sub_class`, must not be `None`")  # noqa: E501

        self._sub_class = sub_class

    @property
    def message(self):
        """Gets the message of this IlmException.  # noqa: E501


        :return: The message of this IlmException.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this IlmException.


        :param message: The message of this IlmException.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def cause_class(self):
        """Gets the cause_class of this IlmException.  # noqa: E501


        :return: The cause_class of this IlmException.  # noqa: E501
        :rtype: str
        """
        return self._cause_class

    @cause_class.setter
    def cause_class(self, cause_class):
        """Sets the cause_class of this IlmException.


        :param cause_class: The cause_class of this IlmException.  # noqa: E501
        :type: str
        """

        self._cause_class = cause_class

    @property
    def server_log_id(self):
        """Gets the server_log_id of this IlmException.  # noqa: E501


        :return: The server_log_id of this IlmException.  # noqa: E501
        :rtype: str
        """
        return self._server_log_id

    @server_log_id.setter
    def server_log_id(self, server_log_id):
        """Sets the server_log_id of this IlmException.


        :param server_log_id: The server_log_id of this IlmException.  # noqa: E501
        :type: str
        """

        self._server_log_id = server_log_id

    @property
    def suppress_stack(self):
        """Gets the suppress_stack of this IlmException.  # noqa: E501


        :return: The suppress_stack of this IlmException.  # noqa: E501
        :rtype: bool
        """
        return self._suppress_stack

    @suppress_stack.setter
    def suppress_stack(self, suppress_stack):
        """Sets the suppress_stack of this IlmException.


        :param suppress_stack: The suppress_stack of this IlmException.  # noqa: E501
        :type: bool
        """
        if suppress_stack is None:
            raise ValueError("Invalid value for `suppress_stack`, must not be `None`")  # noqa: E501

        self._suppress_stack = suppress_stack

    @property
    def suppressed(self):
        """Gets the suppressed of this IlmException.  # noqa: E501


        :return: The suppressed of this IlmException.  # noqa: E501
        :rtype: list[IlmExceptionSuppressed]
        """
        return self._suppressed

    @suppressed.setter
    def suppressed(self, suppressed):
        """Sets the suppressed of this IlmException.


        :param suppressed: The suppressed of this IlmException.  # noqa: E501
        :type: list[IlmExceptionSuppressed]
        """

        self._suppressed = suppressed

    def get_real_child_model(self, data):
        """Returns the real base class specified by the discriminator"""
        discriminator_value = data[self.attribute_map[self.discriminator]]
        return discriminator_value if not(self.__class__.__name__ == discriminator_value) else None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IlmException, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IlmException):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IlmExceptionStackTrace(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'method_name': 'str',
        'file_name': 'str',
        'line_number': 'int',
        'class_name': 'str',
        'native_method': 'bool'
    }

    attribute_map = {
        'method_name': 'methodName',
        'file_name': 'fileName',
        'line_number': 'lineNumber',
        'class_name': 'className',
        'native_method': 'nativeMethod'
    }

    def __init__(self, method_name=None, file_name=None, line_number=None, class_name=None, native_method=None):  # noqa: E501
        """IlmExceptionStackTrace - a model defined in Swagger"""  # noqa: E501
        self._method_name = None
        self._file_name = None
        self._line_number = None
        self._class_name = None
        self._native_method = None
        if not(hasattr(self, "discriminator")) or not(self.discriminator):
            self.discriminator = None
        if method_name is not None:
            self.method_name = method_name
        if file_name is not None:
            self.file_name = file_name
        if line_number is not None:
            self.line_number = line_number
        if class_name is not None:
            self.class_name = class_name
        if native_method is not None:
            self.native_method = native_method

    @property
    def method_name(self):
        """Gets the method_name of this IlmExceptionStackTrace.  # noqa: E501


        :return: The method_name of this IlmExceptionStackTrace.  # noqa: E501
        :rtype: str
        """
        return self._method_name

    @method_name.setter
    def method_name(self, method_name):
        """Sets the method_name of this IlmExceptionStackTrace.


        :param method_name: The method_name of this IlmExceptionStackTrace.  # noqa: E501
        :type: str
        """

        self._method_name = method_name

    @property
    def file_name(self):
        """Gets the file_name of this IlmExceptionStackTrace.  # noqa: E501


        :return: The file_name of this IlmExceptionStackTrace.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this IlmExceptionStackTrace.


        :param file_name: The file_name of this IlmExceptionStackTrace.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def line_number(self):
        """Gets the line_number of this IlmExceptionStackTrace.  # noqa: E501


        :return: The line_number of this IlmExceptionStackTrace.  # noqa: E501
        :rtype: int
        """
        return self._line_number

    @line_number.setter
    def line_number(self, line_number):
        """Sets the line_number of this IlmExceptionStackTrace.


        :param line_number: The line_number of this IlmExceptionStackTrace.  # noqa: E501
        :type: int
        """

        self._line_number = line_number

    @property
    def class_name(self):
        """Gets the class_name of this IlmExceptionStackTrace.  # noqa: E501


        :return: The class_name of this IlmExceptionStackTrace.  # noqa: E501
        :rtype: str
        """
        return self._class_name

    @class_name.setter
    def class_name(self, class_name):
        """Sets the class_name of this IlmExceptionStackTrace.


        :param class_name: The class_name of this IlmExceptionStackTrace.  # noqa: E501
        :type: str
        """

        self._class_name = class_name

    @property
    def native_method(self):
        """Gets the native_method of this IlmExceptionStackTrace.  # noqa: E501


        :return: The native_method of this IlmExceptionStackTrace.  # noqa: E501
        :rtype: bool
        """
        return self._native_method

    @native_method.setter
    def native_method(self, native_method):
        """Sets the native_method of this IlmExceptionStackTrace.


        :param native_method: The native_method of this IlmExceptionStackTrace.  # noqa: E501
        :type: bool
        """

        self._native_method = native_method

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IlmExceptionStackTrace, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IlmExceptionStackTrace):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from af_licence_manager.models.ilm_exception import IlmException  # noqa: F401,E501

class ScriptException(IlmException):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'script_type': 'str',
        'script_name': 'str',
        'script_body': 'str'
    }
    if hasattr(IlmException, "swagger_types"):
        swagger_types.update(IlmException.swagger_types)

    attribute_map = {
        'script_type': 'scriptType',
        'script_name': 'scriptName',
        'script_body': 'scriptBody'
    }
    if hasattr(IlmException, "attribute_map"):
        attribute_map.update(IlmException.attribute_map)

    discriminator_value_class_map = {
          'ScriptEvaluationException': 'ScriptEvaluationException',
'ScriptEnvironmentException': 'ScriptEnvironmentException'    }

    def __init__(self, script_type=None, script_name=None, script_body=None, *args, **kwargs):  # noqa: E501
        """ScriptException - a model defined in Swagger"""  # noqa: E501
        self._script_type = None
        self._script_name = None
        self._script_body = None
        if not(hasattr(self, "discriminator")) or not(self.discriminator):
            self.discriminator = 'sub_class'
        self.script_type = script_type
        if script_name is not None:
            self.script_name = script_name
        self.script_body = script_body
        IlmException.__init__(self, *args, **kwargs)

    @property
    def script_type(self):
        """Gets the script_type of this ScriptException.  # noqa: E501


        :return: The script_type of this ScriptException.  # noqa: E501
        :rtype: str
        """
        return self._script_type

    @script_type.setter
    def script_type(self, script_type):
        """Sets the script_type of this ScriptException.


        :param script_type: The script_type of this ScriptException.  # noqa: E501
        :type: str
        """
        if script_type is None:
            raise ValueError("Invalid value for `script_type`, must not be `None`")  # noqa: E501

        self._script_type = script_type

    @property
    def script_name(self):
        """Gets the script_name of this ScriptException.  # noqa: E501


        :return: The script_name of this ScriptException.  # noqa: E501
        :rtype: str
        """
        return self._script_name

    @script_name.setter
    def script_name(self, script_name):
        """Sets the script_name of this ScriptException.


        :param script_name: The script_name of this ScriptException.  # noqa: E501
        :type: str
        """

        self._script_name = script_name

    @property
    def script_body(self):
        """Gets the script_body of this ScriptException.  # noqa: E501


        :return: The script_body of this ScriptException.  # noqa: E501
        :rtype: str
        """
        return self._script_body

    @script_body.setter
    def script_body(self, script_body):
        """Sets the script_body of this ScriptException.


        :param script_body: The script_body of this ScriptException.  # noqa: E501
        :type: str
        """
        if script_body is None:
            raise ValueError("Invalid value for `script_body`, must not be `None`")  # noqa: E501

        self._script_body = script_body

    def get_real_child_model(self, data):
        """Returns the real base class specified by the discriminator"""
        discriminator_value = data[self.attribute_map[self.discriminator]]
        return discriminator_value if not(self.__class__.__name__ == discriminator_value) else None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScriptException, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScriptException):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from af_licence_manager.models.ilm_exception import IlmException  # noqa: F401,E501

class InvalidInstanceStateException(IlmException):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'instance_id': 'str',
        'execution_state': 'str',
        'migration_state': 'str',
        'preventing_status': 'str'
    }
    if hasattr(IlmException, "swagger_types"):
        swagger_types.update(IlmException.swagger_types)

    attribute_map = {
        'instance_id': 'instanceId',
        'execution_state': 'executionState',
        'migration_state': 'migrationState',
        'preventing_status': 'preventingStatus'
    }
    if hasattr(IlmException, "attribute_map"):
        attribute_map.update(IlmException.attribute_map)

    def __init__(self, instance_id=None, execution_state=None, migration_state=None, preventing_status=None, *args, **kwargs):  # noqa: E501
        """InvalidInstanceStateException - a model defined in Swagger"""  # noqa: E501
        self._instance_id = None
        self._execution_state = None
        self._migration_state = None
        self._preventing_status = None
        if not(hasattr(self, "discriminator")) or not(self.discriminator):
            self.discriminator = None
        self.instance_id = instance_id
        if execution_state is not None:
            self.execution_state = execution_state
        if migration_state is not None:
            self.migration_state = migration_state
        self.preventing_status = preventing_status
        IlmException.__init__(self, *args, **kwargs)

    @property
    def instance_id(self):
        """Gets the instance_id of this InvalidInstanceStateException.  # noqa: E501


        :return: The instance_id of this InvalidInstanceStateException.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this InvalidInstanceStateException.


        :param instance_id: The instance_id of this InvalidInstanceStateException.  # noqa: E501
        :type: str
        """
        if instance_id is None:
            raise ValueError("Invalid value for `instance_id`, must not be `None`")  # noqa: E501

        self._instance_id = instance_id

    @property
    def execution_state(self):
        """Gets the execution_state of this InvalidInstanceStateException.  # noqa: E501


        :return: The execution_state of this InvalidInstanceStateException.  # noqa: E501
        :rtype: str
        """
        return self._execution_state

    @execution_state.setter
    def execution_state(self, execution_state):
        """Sets the execution_state of this InvalidInstanceStateException.


        :param execution_state: The execution_state of this InvalidInstanceStateException.  # noqa: E501
        :type: str
        """
        allowed_values = ["IE_RUNNING", "IE_SUSPENDED", "IE_SOFTLY_SUSPENDED", "IE_ABORTED", "IE_SOFTLY_ABORTED", "IE_FINISHED"]  # noqa: E501
        if execution_state not in allowed_values:
            raise ValueError(
                "Invalid value for `execution_state` ({0}), must be one of {1}"  # noqa: E501
                .format(execution_state, allowed_values)
            )

        self._execution_state = execution_state

    @property
    def migration_state(self):
        """Gets the migration_state of this InvalidInstanceStateException.  # noqa: E501


        :return: The migration_state of this InvalidInstanceStateException.  # noqa: E501
        :rtype: str
        """
        return self._migration_state

    @migration_state.setter
    def migration_state(self, migration_state):
        """Sets the migration_state of this InvalidInstanceStateException.


        :param migration_state: The migration_state of this InvalidInstanceStateException.  # noqa: E501
        :type: str
        """
        allowed_values = ["IM_MIGRATABLE", "IM_MIGRATING", "IM_NOT_MIGRATABLE"]  # noqa: E501
        if migration_state not in allowed_values:
            raise ValueError(
                "Invalid value for `migration_state` ({0}), must be one of {1}"  # noqa: E501
                .format(migration_state, allowed_values)
            )

        self._migration_state = migration_state

    @property
    def preventing_status(self):
        """Gets the preventing_status of this InvalidInstanceStateException.  # noqa: E501


        :return: The preventing_status of this InvalidInstanceStateException.  # noqa: E501
        :rtype: str
        """
        return self._preventing_status

    @preventing_status.setter
    def preventing_status(self, preventing_status):
        """Sets the preventing_status of this InvalidInstanceStateException.


        :param preventing_status: The preventing_status of this InvalidInstanceStateException.  # noqa: E501
        :type: str
        """
        if preventing_status is None:
            raise ValueError("Invalid value for `preventing_status`, must not be `None`")  # noqa: E501

        self._preventing_status = preventing_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvalidInstanceStateException, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvalidInstanceStateException):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EbpInstanceReference(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'instance_id': 'str',
        'instance_log_id': 'str',
        'base_template_id': 'str',
        'node_id': 'int',
        'node_iteration': 'int',
        'execution_manager_uris': 'list[str]',
        'runtime_manager_uris': 'list[str]'
    }

    attribute_map = {
        'type': 'type',
        'instance_id': 'instanceId',
        'instance_log_id': 'instanceLogId',
        'base_template_id': 'baseTemplateId',
        'node_id': 'nodeId',
        'node_iteration': 'nodeIteration',
        'execution_manager_uris': 'executionManagerUris',
        'runtime_manager_uris': 'runtimeManagerUris'
    }

    def __init__(self, type=None, instance_id=None, instance_log_id=None, base_template_id=None, node_id=None, node_iteration=None, execution_manager_uris=None, runtime_manager_uris=None):  # noqa: E501
        """EbpInstanceReference - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._instance_id = None
        self._instance_log_id = None
        self._base_template_id = None
        self._node_id = None
        self._node_iteration = None
        self._execution_manager_uris = None
        self._runtime_manager_uris = None
        if not(hasattr(self, "discriminator")) or not(self.discriminator):
            self.discriminator = None
        self.type = type
        self.instance_id = instance_id
        self.instance_log_id = instance_log_id
        self.base_template_id = base_template_id
        self.node_id = node_id
        self.node_iteration = node_iteration
        self.execution_manager_uris = execution_manager_uris
        if runtime_manager_uris is not None:
            self.runtime_manager_uris = runtime_manager_uris

    @property
    def type(self):
        """Gets the type of this EbpInstanceReference.  # noqa: E501


        :return: The type of this EbpInstanceReference.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EbpInstanceReference.


        :param type: The type of this EbpInstanceReference.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["NULL", "ACTIVITY", "DECISION_ACTIVITY", "LWP", "TLPI"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def instance_id(self):
        """Gets the instance_id of this EbpInstanceReference.  # noqa: E501


        :return: The instance_id of this EbpInstanceReference.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this EbpInstanceReference.


        :param instance_id: The instance_id of this EbpInstanceReference.  # noqa: E501
        :type: str
        """
        if instance_id is None:
            raise ValueError("Invalid value for `instance_id`, must not be `None`")  # noqa: E501

        self._instance_id = instance_id

    @property
    def instance_log_id(self):
        """Gets the instance_log_id of this EbpInstanceReference.  # noqa: E501


        :return: The instance_log_id of this EbpInstanceReference.  # noqa: E501
        :rtype: str
        """
        return self._instance_log_id

    @instance_log_id.setter
    def instance_log_id(self, instance_log_id):
        """Sets the instance_log_id of this EbpInstanceReference.


        :param instance_log_id: The instance_log_id of this EbpInstanceReference.  # noqa: E501
        :type: str
        """
        if instance_log_id is None:
            raise ValueError("Invalid value for `instance_log_id`, must not be `None`")  # noqa: E501

        self._instance_log_id = instance_log_id

    @property
    def base_template_id(self):
        """Gets the base_template_id of this EbpInstanceReference.  # noqa: E501


        :return: The base_template_id of this EbpInstanceReference.  # noqa: E501
        :rtype: str
        """
        return self._base_template_id

    @base_template_id.setter
    def base_template_id(self, base_template_id):
        """Sets the base_template_id of this EbpInstanceReference.


        :param base_template_id: The base_template_id of this EbpInstanceReference.  # noqa: E501
        :type: str
        """
        if base_template_id is None:
            raise ValueError("Invalid value for `base_template_id`, must not be `None`")  # noqa: E501

        self._base_template_id = base_template_id

    @property
    def node_id(self):
        """Gets the node_id of this EbpInstanceReference.  # noqa: E501


        :return: The node_id of this EbpInstanceReference.  # noqa: E501
        :rtype: int
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this EbpInstanceReference.


        :param node_id: The node_id of this EbpInstanceReference.  # noqa: E501
        :type: int
        """
        if node_id is None:
            raise ValueError("Invalid value for `node_id`, must not be `None`")  # noqa: E501

        self._node_id = node_id

    @property
    def node_iteration(self):
        """Gets the node_iteration of this EbpInstanceReference.  # noqa: E501


        :return: The node_iteration of this EbpInstanceReference.  # noqa: E501
        :rtype: int
        """
        return self._node_iteration

    @node_iteration.setter
    def node_iteration(self, node_iteration):
        """Sets the node_iteration of this EbpInstanceReference.


        :param node_iteration: The node_iteration of this EbpInstanceReference.  # noqa: E501
        :type: int
        """
        if node_iteration is None:
            raise ValueError("Invalid value for `node_iteration`, must not be `None`")  # noqa: E501

        self._node_iteration = node_iteration

    @property
    def execution_manager_uris(self):
        """Gets the execution_manager_uris of this EbpInstanceReference.  # noqa: E501


        :return: The execution_manager_uris of this EbpInstanceReference.  # noqa: E501
        :rtype: list[str]
        """
        return self._execution_manager_uris

    @execution_manager_uris.setter
    def execution_manager_uris(self, execution_manager_uris):
        """Sets the execution_manager_uris of this EbpInstanceReference.


        :param execution_manager_uris: The execution_manager_uris of this EbpInstanceReference.  # noqa: E501
        :type: list[str]
        """
        if execution_manager_uris is None:
            raise ValueError("Invalid value for `execution_manager_uris`, must not be `None`")  # noqa: E501

        self._execution_manager_uris = execution_manager_uris

    @property
    def runtime_manager_uris(self):
        """Gets the runtime_manager_uris of this EbpInstanceReference.  # noqa: E501


        :return: The runtime_manager_uris of this EbpInstanceReference.  # noqa: E501
        :rtype: list[str]
        """
        return self._runtime_manager_uris

    @runtime_manager_uris.setter
    def runtime_manager_uris(self, runtime_manager_uris):
        """Sets the runtime_manager_uris of this EbpInstanceReference.


        :param runtime_manager_uris: The runtime_manager_uris of this EbpInstanceReference.  # noqa: E501
        :type: list[str]
        """

        self._runtime_manager_uris = runtime_manager_uris

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EbpInstanceReference, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EbpInstanceReference):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from af_licence_manager.api.arista_flow_service_api import AristaFlowServiceApi
from af_licence_manager.api.licence_manager_api import LicenceManagerApi
from af_licence_manager.api.default_api import DefaultApi



# coding: utf-8

"""
    AristaFlowREST/LicenceManager

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import af_licence_manager
from af_licence_manager.api.arista_flow_service_api import AristaFlowServiceApi  # noqa: E501
from af_licence_manager.rest import ApiException


class TestAristaFlowServiceApi(unittest.TestCase):
    """AristaFlowServiceApi unit test stubs"""

    def setUp(self):
        self.api = AristaFlowServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_release(self):
        """Test case for get_release

        """
        pass

    def test_get_service_instance_name(self):
        """Test case for get_service_instance_name

        """
        pass

    def test_get_uris(self):
        """Test case for get_uris

        """
        pass

    def test_ping(self):
        """Test case for ping

        """
        pass

    def test_register_sse(self):
        """Test case for register_sse

        """
        pass

    def test_unregister_sse(self):
        """Test case for unregister_sse

        """
        pass


if __name__ == '__main__':
    unittest.main()
